platform: msm_shared: Ignore command timeout during tuning

Ignore command timeouts along with command crc and end bit
errors

Change-Id: I5291e5ab2c87b21dd1ae9cc017769e8a7f475781
diff --git a/platform/msm_shared/sdhci.c b/platform/msm_shared/sdhci.c
index e81d4ed..a9bb1a4 100644
--- a/platform/msm_shared/sdhci.c
+++ b/platform/msm_shared/sdhci.c
@@ -444,12 +444,13 @@
 			break;
 
 		/*
 		 * If Tuning is in progress ignore cmd crc & cmd end bit errors
 		 */
 		if (host->tuning_in_progress)
 		{
 			err_status = REG_READ16(host, SDHCI_ERR_INT_STS_REG);
-			if ((err_status & SDHCI_CMD_CRC_MASK) || (err_status & SDHCI_DAT_END_BIT_MASK))
+			if ((err_status & SDHCI_CMD_CRC_MASK) || (err_status & SDHCI_DAT_END_BIT_MASK)
+				|| err_status & SDHCI_CMD_TIMEOUT_MASK)
 			{
 				sdhci_reset(host, (SOFT_RESET_CMD | SOFT_RESET_DATA));
 				return 0;
@@ -444,12 +444,13 @@
 
 		/*
-		 * If Tuning is in progress ignore cmd crc & cmd end bit errors
+		 * If Tuning is in progress ignore cmd crc, cmd timeout & cmd end bit errors
 		 */
 		if (host->tuning_in_progress)